@@ -15,7 +15,7 @@ c         lund or nucrin branch point: total  energy
 
          real*8 eintmn/0.2/
 c
-         real*8 elab, ek
+         real*8 elab, ek, u, alpha
 
          elab=pj.fm.p(4)
          ek = elab - pj.mass
@@ -51,7 +51,13 @@ c              move incident to a:
             np=1
             a(1) = pj
 c              reduce energy (evaporation etc)
-            a(1).fm.p(4) = a(1).mass + ek/2
+            alpha =( (ia-1.0)/(ia+1.0) )**2
+c              Elastic scattering: E1--> E2
+c             E2/E1 = (A**2 + 2Acos + 1)/(A+1)**2 = 1/2 ((alpha+1) + (1-alpha)*cos)
+c            assume isotroic; then E2  is uniform in (Alpha, 1)E1
+c              
+            call rndc(u)
+            a(1).fm.p(4) = a(1).mass + ek*((1.0-alpha)*u+alpha)
             call cadjm(a(1), a(1))
          endif
        end
