@@ -113,7 +113,7 @@ c     *
       integer  EventNo
       integer i, j
       integer seed(2)
-      real*8 svEasWait, svEthin, kepn
+      real*8 svEasWait, svEthin(2), kepn
 
       
       Np = 0
@@ -125,10 +125,12 @@ c     *
       Ethresh = kepn * WaitRatio
 
       svEasWait = EasWait       ! for safety save
-      svEthin = Ethin           ! //
+      svEthin(1) = Ethin(1)           ! //
+      svEthin(2) = Ethin(2)           ! //
       call csetEmin(Generate2, KEminObs2, Cutneg, Cuteg)
       EasWait = svEasWait       ! restore
-      Ethin = svEthin
+      Ethin(1) = svEthin(1)
+      Ethin(2) = svEthin(2)
 
       rewind  Wdev
 
@@ -630,6 +632,8 @@ c      call cqIncident(incident, angle)
 
       write(to) cumnum, num, irevent,  Zfirst
       call cputHES(to)   ! put high energy showers.
+      write(0,*) ' first Z=',Zfirst.pos.depth*0.1, ' g/cm2',
+     *  Zfirst.pos.height, ' m' 
       
       call cputNodInfo(from, to)  ! put nordal info.
 
