@@ -49,9 +49,17 @@ c           at flesh time, you don't need to rewrite Job
          endif
          call cwriteParam(TempDev, 1)
          close(TempDev)
+
+c           macIFC/MACOSX cannot put correct namelist char data 
+c           (' is missing) so cannot read SkeletonFile
+c           avoid read it. the user must do the equiv.  by hand 
+#if ! defined (MacIFC) && ! defined (MACOSX)         
+c  
+         write(0,*) '*********************************bad'
          call copenNLf(TempDev, SkeletonFile, icon)
          call creadParam(TempDev)
          close(TempDev)
+#endif
 c            restore Job
          Job = temp
       endif
