@@ -328,6 +328,16 @@ c
         PrimaryIdTbl(53).subcode = -1
         PrimaryIdTbl(53).charge = 1
 
+        PrimaryIdTbl(54).symb = 'pbar'
+        PrimaryIdTbl(54).code = knuc
+        PrimaryIdTbl(54).subcode = antip
+        PrimaryIdTbl(54).charge = -1
+
+        PrimaryIdTbl(55).symb = 'nbar'
+        PrimaryIdTbl(55).code = knuc
+        PrimaryIdTbl(55).subcode = antip
+        PrimaryIdTbl(55).charge = 0
+
         
        end
 c***************************************************
