@@ -12,10 +12,18 @@ c       of cutoff rigidities.
 c
       real*8 azmin  ! input. value of azimuth angle at a given location.
                    !         deg.
+                   ! For format# 5, this is longitude of a place
       real*8 zen   ! input. value of zenith angle at a given location. 
                    !     It may be deg, or cos, depending on the table.
+                   ! For format# 5, this is latitude of the place.
+                   !     It may be deg, or cos, depending on the table.
       real*8 rig   ! input. value of particle rigidity (GV) p/Z
+
       real*8 prob  ! output. probability that 'r' can enter the earth.
+                   !  For format# 5, this is  0 or 1. 1 dose not necessary
+                   !   mean that the particle can enter the earth;
+                   !   there is possibility so you have to examine.
+                   !   if 0, there is no possibility so you may discard it.
 c
 c      Note: This system cannot treat multiple locations at a time.
 c
@@ -25,11 +33,15 @@ c
       real*8  azm
 
       integer i1, i2, i3
+
+      azm = azmin
       if(azm .lt. 0.) then
          azm = azm + 360.
+      else
+         azm = mod(azm, 360.d0)
       endif
-      azm = mod(azmin, 360.d0)
-      if(Rdatafmt .eq. 1) then
+
+      if(Rdatafmt .eq. 1 ) then
          call k4ptdi(RigCutTbl, AzmSize, ZenSize, AzmSize, MinAzm, 
      *        MinZen, DAzm,  DZen,  azm, zen, rigcut)
          if(rig .lt. rigcut) then
@@ -37,7 +49,7 @@ c
          else
             prob = 1.
          endif
-      else
+      elseif(Rdatafmt .le. 4) then
 c         i3 = log10(rig/MinRig)/LogDRig + 1
 c         i3 <= log10(rig)*20 < i3+1 (i3=0,1..)
 c         logrig = log10(rig)/LogDRig
@@ -65,13 +77,46 @@ c         dlogrig=(logrig - (i3-1))*LogDRig
      *    RigTbl2, ZenSize, AzmSize, RigSize, i1, i2, i3,
      *    prob ) 
          prob = min(prob, 1.d0)
+      elseif( Rdatafmt .eq. 5) then
+c           essentiall the same as 1 case. but rather should not
+c           make interpolation
+         call k2dtblv(RigCutTbl, AzmSize, ZenSize, AzmSize, MinAzm, 
+     *        MinZen, DAzm,  DZen,  azm, zen, rigcut)
+         if(rig .lt. rigcut) then
+            prob = 0.
+         else
+            prob = 1.
+         endif
+      else
+         call cerrorMsg('format # error in rigidity table',0)
       endif
  100  continue
       end
+      subroutine k2dtblv(tbl, xs, ys, adj, xm, 
+     *        ym, dx,  dy,  x, y,  ans)
+      integer xs
+      integer ys
+      integer adj
+      real*8 xm
+      real*8 ym
+      real*8 dx
+      real*8 dy
+      real*8 x, y
+      real*8 ans
+      real*8 tbl(adj, ys)
+      
+      integer i, j
+      
+      i = (x-xm)/dx + 1
+      j = (y-ym)/dy + 1
+      ans = tbl(i,j)
+      end
+
+
       subroutine cgetrigCut(azmin, zen, rigcut)
       implicit none
 #include "ZrigCut.h"
-c         get rigidity cut (for old table only)
+c         get rigidity cut (for old table only); use crigCut now
 c
       real*8 azmin  ! input. value of azimuth angle at a given location.
                    !         deg.
@@ -139,6 +184,8 @@ c
          call crigCutfmt2
       elseif(Rdatafmt .eq. 4) then
          call crigCutfmt4
+      elseif(Rdatafmt .eq. 5) then
+         call crigCutfmt5
       else
          write(msg, *) 'rigidity cut data format =',Rdatafmt,
      *   ' ivalid' 
@@ -219,10 +266,10 @@ c      ******************
 
 
        integer i, j, ios
-       character*100 msg
+       character*150 msg
 
        do   j=1,  zen
-           read(io,'(13f6.2)', iostat=ios) ( tbl(i, j), i = 1, azm)
+           read(io, *, iostat=ios) ( tbl(i, j), i = 1, azm)
            if(ios .ne. 0) then
               write(msg, *) 'Unexpected EOF at rigicity table reading'
               call cerrorMsg(msg, 1)
@@ -433,4 +480,66 @@ c       read cut off table for format 4
       end
 
 
+c     **********************
+      subroutine crigCutfmt5
+      implicit none
+#include "Zmanagerp.h"
+#include "ZrigCut.h"
+
+      character*192 msg
+
+      integer icon
+
+
+      read(TempDev, *)   ! skip
+      read(TempDev, *)
+     *  ZenValue, ZenMax, DZen, ZenSize,
+     *  AzmValue, MinAzm, DAzm, AzmSize
+
+
+c           skip until -------------- line
+      call cskipComment(TempDev, icon)
+      if(icon .ne. 0) then
+          call cerrorMsg('cut-off table data has no ---- line', 0)
+      endif
+
+      if(AzmValue .eq. 'deg') then
+c               assume min of logitudinal angle is  0 deg.
+          MinAzm = 0.
+          if( (AzmSize - 1)* DAzm  .lt. (360.d0- DAzm* 0.1d0) ) then
+c                 fill the last col.  by the first col.
+             call creadRigCut(TempDev, RigCutTbl, AzmSize, ZenSize, 
+     *       AzmSize+1)
+             AzmSize = AzmSize + 1
+             call cfillRigCut(RigCutTbl, AzmSize, ZenSize)
+          else
+             call creadRigCut(TempDev, RigCutTbl, AzmSize, ZenSize,
+     *        AzmSize)
+          endif
+          close(TempDev)
+       else
+          write(msg, *)
+     *    ' Azimuthal angle unit must be deg for rigidity cut table'
+          call cerrorMsg(msg, 1)
+          write(msg, *) ' But it is ', AzmValue
+          call cerrorMsg(msg, 0)
+       endif
+
+
+       if(ZenValue .eq. 'cos') then
+c              DZen should be negative and min is 1.0
+          MinZen = 1.0
+          if(DZen .ge. 0.) then
+             write(msg, *)
+     *        ' step of Zenith angle for rigidity cut should be < 0'
+             call cerrorMsg(msg, 1)
+             write(msg, *) ' because you give it in cos value'
+             call cerrorMsg(msg, 0)
+          endif
+       endif
+c
+c                                   
+       write(msg,*) 'Rough rigidity cut-off table has been read:'
+       call cerrorMsg(msg, 1)
+      end
 
